==> external-system-192.6817.11-sources.jar: com/intellij/openapi/externalSystem/util/ExternalSystemConstants.java <==
/*
 * Copyright 2000-2017 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.openapi.externalSystem.util;

import com.intellij.openapi.roots.ExternalProjectSystemRegistry;
import com.intellij.util.SystemProperties;
import org.jetbrains.annotations.NonNls;
import org.jetbrains.annotations.NotNull;

public class ExternalSystemConstants {
  @NonNls @NotNull public static final String EXTERNAL_SYSTEM_ID_KEY  = ExternalProjectSystemRegistry.EXTERNAL_SYSTEM_ID_KEY;

  @NotNull @NonNls public static final String USE_IN_PROCESS_COMMUNICATION_REGISTRY_KEY_SUFFIX = ".system.in.process";
  @NotNull @NonNls public static final String EXTERNAL_SYSTEM_REMOTE_COMMUNICATION_MANAGER_DEBUG_PORT
    = "external.system.remote.communication.manager.debug.port";

  @NotNull public static final String DEBUG_RUNNER_ID = "ExternalSystemTaskDebugRunner";
  @NotNull public static final String RUNNER_ID       = "ExternalSystemTaskRunner";

  public static final boolean VERBOSE_PROCESSING       = SystemProperties.getBooleanProperty("external.system.verbose.processing", false);

  public static final char PATH_SEPARATOR = '/';

  // Order.
  public static final int BUILTIN_PROJECT_DATA_SERVICE_ORDER = Integer.MIN_VALUE;
  public static final int BUILTIN_MODULE_DATA_SERVICE_ORDER = BUILTIN_PROJECT_DATA_SERVICE_ORDER + 10;
  public static final int BUILTIN_LIBRARY_DATA_SERVICE_ORDER = BUILTIN_MODULE_DATA_SERVICE_ORDER + 10;
  public static final int BUILTIN_SERVICE_ORDER = BUILTIN_LIBRARY_DATA_SERVICE_ORDER + 10;
  public static final int BUILTIN_TOOL_WINDOW_SERVICE_ORDER = BUILTIN_SERVICE_ORDER + 10;
  public static final int UNORDERED = 1000;
}

==> external-system-203.6682.86-sources.jar: com/intellij/openapi/externalSystem/util/ExternalSystemConstants.java <==
// Copyright 2000-2020 JetBrains s.r.o. Use of this source code is governed by the Apache 2.0 license that can be found in the LICENSE file.
package com.intellij.openapi.externalSystem.util;

import com.intellij.openapi.roots.ExternalProjectSystemRegistry;
import com.intellij.util.SystemProperties;
import org.jetbrains.annotations.NonNls;
import org.jetbrains.annotations.NotNull;

public final class ExternalSystemConstants {
  @NonNls @NotNull public static final String EXTERNAL_SYSTEM_ID_KEY  = ExternalProjectSystemRegistry.EXTERNAL_SYSTEM_ID_KEY;

  @NotNull @NonNls public static final String USE_IN_PROCESS_COMMUNICATION_REGISTRY_KEY_SUFFIX = ".system.in.process";
  @NotNull @NonNls public static final String EXTERNAL_SYSTEM_REMOTE_COMMUNICATION_MANAGER_DEBUG_PORT
    = "external.system.remote.communication.manager.debug.port";

  @NotNull public static final String DEBUG_RUNNER_ID = "ExternalSystemTaskDebugRunner";
  @NotNull public static final String RUNNER_ID       = "ExternalSystemTaskRunner";

  public static final boolean VERBOSE_PROCESSING       = SystemProperties.getBooleanProperty("external.system.verbose.processing", false);

  public static final char PATH_SEPARATOR = '/';

  // Order.
  public static final int BUILTIN_PROJECT_DATA_SERVICE_ORDER = Integer.MIN_VALUE;
  public static final int BUILTIN_MODULE_DATA_SERVICE_ORDER = BUILTIN_PROJECT_DATA_SERVICE_ORDER + 10;
  public static final int BUILTIN_LIBRARY_DATA_SERVICE_ORDER = BUILTIN_MODULE_DATA_SERVICE_ORDER + 10;
  public static final int BUILTIN_SERVICE_ORDER = BUILTIN_LIBRARY_DATA_SERVICE_ORDER + 10;
  public static final int BUILTIN_TOOL_WINDOW_SERVICE_ORDER = BUILTIN_SERVICE_ORDER + 10;
  public static final int UNORDERED = 1000;
}
